==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/FileDialogs/TwoPanelFileDialog/translations/two_panel_file_dialog_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>TwoPanelFileDialog</name>
    <message>
        <location filename="../twopanelfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Tambah File</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="70"/>
        <source>File name:</source>
        <translation>Nama file:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="80"/>
        <source>Files of type:</source>
        <translation>Tipe file:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="117"/>
        <source>Play</source>
        <translation>Mainkan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="130"/>
        <source>Add</source>
        <translation>Tambahkan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="143"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogFactory</name>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="68"/>
        <location filename="../twopanelfiledialog.cpp" line="78"/>
        <source>Two-panel File Dialog</source>
        <translation>Dialog File Panel Kedua</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="77"/>
        <source>About Two-panel File Dialog</source>
        <translation>Tentang Dialog File Two-panel</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="79"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="80"/>
        <source>Based on code from the Qt library</source>
        <translation>Berdasarkan pada kode dari pustaka Qt</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogImpl</name>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="322"/>
        <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="340"/>
        <source>Directories</source>
        <translation>Direktori</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="352"/>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="459"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 sudah ada.
Apakah kamu ingin menggantinya?</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/FileDialogs/TwoPanelFileDialog/translations/two_panel_file_dialog_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>TwoPanelFileDialog</name>
    <message>
        <location filename="../twopanelfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Tambah File</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="70"/>
        <source>File name:</source>
        <translation>Nama file:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="80"/>
        <source>Files of type:</source>
        <translation>Tipe file:</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="117"/>
        <source>Play</source>
        <translation>Mainkan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="130"/>
        <source>Add</source>
        <translation>Tambahkan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.ui" line="143"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogFactory</name>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="67"/>
        <location filename="../twopanelfiledialog.cpp" line="77"/>
        <source>Two-panel File Dialog</source>
        <translation>Dialog File Panel Kedua</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="76"/>
        <source>About Two-panel File Dialog</source>
        <translation>Tentang Dialog File Two-panel</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="78"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialog.cpp" line="79"/>
        <source>Based on code from the Qt library</source>
        <translation>Berdasarkan pada kode dari pustaka Qt</translation>
    </message>
</context>
<context>
    <name>TwoPanelFileDialogImpl</name>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="322"/>
        <location filename="../twopanelfiledialogimpl.cpp" line="338"/>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="340"/>
        <source>Directories</source>
        <translation>Direktori</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="352"/>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <location filename="../twopanelfiledialogimpl.cpp" line="459"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 sudah ada.
Apakah kamu ingin menggantinya?</translation>
    </message>
</context>
</TS>
